==> AsposeCellsCloud-CellsApi-25.12.tar.gz: AsposeCellsCloud-CellsApi-25.12/docs/model/Worksheet.md <==
# AsposeCellsCloud::Object::Worksheet 

## Load the model package
```perl
use AsposeCellsCloud::Object::Worksheet;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**Links** | **ARRAY[Link]** | Property Summary: Contains a list of links represented by the class link. |
**DisplayRightToLeft** | **boolean** | Indicates if the specified worksheet is displayed from right to left instead of from left to right.            Default is false.  |
**DisplayZeros** | **boolean** | True if zero values are displayed.  |
**FirstVisibleColumn** | **int** | Represents first visible column index.  |
**FirstVisibleRow** | **int** | Represents first visible row index.  |
**Name** | **string** | Gets or sets the name of the worksheet.  |
**Index** | **int** | Gets the index of sheet in the worksheet collection.  |
**IsGridlinesVisible** | **boolean** | Gets or sets a value indicating whether the gridlines are visible.Default is true.  |
**IsOutlineShown** | **boolean** | Indicates whether to show outline.  |
**IsPageBreakPreview** | **boolean** | Indicates whether the specified worksheet is shown in normal view or page break preview.  |
**IsVisible** | **boolean** | Represents if the worksheet is visible.  |
**IsProtected** | **boolean** | Indicates if the worksheet is protected.  |
**IsRowColumnHeadersVisible** | **boolean** | Gets or sets a value indicating whether the worksheet will display row and column headers.            Default is true.  |
**IsRulerVisible** | **boolean** | Indicates whether the ruler is visible. This property is only applied for page break preview.  |
**IsSelected** | **boolean** | Indicates whether this worksheet is selected when the workbook is opened.  |
**TabColor** | **Color** | Represents worksheet tab color.  |
**TransitionEntry** | **boolean** | Indicates whether the Transition Formula Entry (Lotus compatibility) option is enabled.  |
**TransitionEvaluation** | **boolean** | Indicates whether the Transition Formula Evaluation (Lotus compatibility) option is enabled.  |
**Type** | **string** | Represents worksheet type.  |
**ViewType** | **string** | Gets and sets the view type.  |
**VisibilityType** | **string** | Indicates the visible state for this sheet.  |
**Zoom** | **int** | Represents the scaling factor in percentage. It should be between 10 and 400.  |
**Cells** | **LinkElement** | Gets the  collection.  |
**Charts** | **LinkElement** | Gets a  collection  |
**AutoShapes** | **LinkElement** |  |
**OleObjects** | **LinkElement** | Represents a collection of  in a worksheet.  |
**Comments** | **LinkElement** | Gets the  collection.  |
**Pictures** | **LinkElement** | Gets a  collection.  |
**MergedCells** | **LinkElement** |  |
**Validations** | **LinkElement** | Gets the data validation setting collection in the worksheet.  |
**ConditionalFormattings** | **LinkElement** | Gets the ConditionalFormattings in the worksheet.  |
**Hyperlinks** | **LinkElement** | Gets the  collection.  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/Worksheet.md <==
# AsposeCellsCloud::Object::Worksheet 

## Load the model package
```perl
use AsposeCellsCloud::Object::Worksheet;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**Links** | **ARRAY[Link]** | Property Summary: Contains a list of links represented by the class link. |
**DisplayRightToLeft** | **boolean** | Indicates if the specified worksheet is displayed from right to left instead of from left to right.            Default is false.  |
**DisplayZeros** | **boolean** | True if zero values are displayed.  |
**FirstVisibleColumn** | **int** | Represents first visible column index.  |
**FirstVisibleRow** | **int** | Represents first visible row index.  |
**Name** | **string** | Gets or sets the name of the worksheet.  |
**Index** | **int** | Gets the index of sheet in the worksheet collection.  |
**IsGridlinesVisible** | **boolean** | Gets or sets a value indicating whether the gridlines are visible.Default is true.  |
**IsOutlineShown** | **boolean** | Indicates whether to show outline.  |
**IsPageBreakPreview** | **boolean** | Indicates whether the specified worksheet is shown in normal view or page break preview.  |
**IsVisible** | **boolean** | Represents if the worksheet is visible.  |
**IsProtected** | **boolean** | Indicates if the worksheet is protected.  |
**IsRowColumnHeadersVisible** | **boolean** | Gets or sets a value indicating whether the worksheet will display row and column headers.            Default is true.  |
**IsRulerVisible** | **boolean** | Indicates whether the ruler is visible. This property is only applied for page break preview.  |
**IsSelected** | **boolean** | Indicates whether this worksheet is selected when the workbook is opened.  |
**TabColor** | **Color** | Represents worksheet tab color.  |
**TransitionEntry** | **boolean** | Indicates whether the Transition Formula Entry (Lotus compatibility) option is enabled.  |
**TransitionEvaluation** | **boolean** | Indicates whether the Transition Formula Evaluation (Lotus compatibility) option is enabled.  |
**Type** | **string** | Represents worksheet type.  |
**ViewType** | **string** | Gets and sets the view type.  |
**VisibilityType** | **string** | Indicates the visible state for this sheet.  |
**Zoom** | **int** | Represents the scaling factor in percentage. It should be between 10 and 400.  |
**Cells** | **LinkElement** | Gets the  collection.  |
**Charts** | **LinkElement** | Gets a  collection  |
**AutoShapes** | **LinkElement** |  |
**OleObjects** | **LinkElement** | Represents a collection of  in a worksheet.  |
**Comments** | **LinkElement** | Gets the  collection.  |
**Pictures** | **LinkElement** | Gets a  collection.  |
**MergedCells** | **LinkElement** |  |
**Validations** | **LinkElement** | Gets the data validation setting collection in the worksheet.  |
**ConditionalFormattings** | **LinkElement** | Gets the ConditionalFormattings in the worksheet.  |
**Hyperlinks** | **LinkElement** | Gets the  collection.  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
